#ifndef QUEUE_H
#define QUEUE_H

#include <iostream>
#include <memory>
#include <stdexcept>

class CQueue {
private:
    std::unique_ptr<double[]> queue;
    int size;
    int capacity;

public:
    CQueue() noexcept;
    explicit CQueue(int initialCapacity);
    explicit CQueue(std::istream& is);
    CQueue(const CQueue& other);
    ~CQueue();

    void addtoqueue(double value);
    void deletefromqueue();
    int getSize() const noexcept;
    double getMax() const;
    double getMin() const;
    void clear() noexcept;
    bool isEmpty() const noexcept;
    double getQueueElement(int index) const;

    CQueue operator+(const CQueue& other) const;
    CQueue operator-(const CQueue& other) const;
    CQueue operator*(const double scalar) const;

    friend std::ostream& operator<<(std::ostream& os, const CQueue& queue);
    friend std::istream& operator>>(std::istream& is, CQueue& queue);
};

std::ostream& operator<<(std::ostream& os, const CQueue& queue);
std::istream& operator>>(std::istream& is, CQueue& queue);

#endif
